======
pyrato
======

Python Room Acoustics Tools - A collection of functions for commonly used operations in room acoustics

Installation
============

Use pip to install pyrato

.. code-block:: console

    $ pip install pyrato

(Requires Python >= 3.5)


Getting Started
===============

Check out the `examples notebook`_ for a tour of the
functionality and `read the docs`_ for the complete documentation.

Contributing
============

Refer to the `contribution guidelines`_ for more information.

.. _contribution guidelines: https://github.com/mberz/pyrato/blob/main/CONTRIBUTING.rst
.. _examples notebook: https://mybinder.org/v2/gh/mberz/pyrato/HEAD?filepath=examples%2Fenergy_decay_curves_and_reverberation_time.ipynb
.. _read the docs: https://pyrato.readthedocs.io/en/latest
